@@ -111,8 +111,10 @@ pmml.hclust <- function(model,
   #-------------------------------------------------------------------
   # PMML -> Header
 
-  pmml <- append.XMLNode(pmml, .pmmlHeader(description, copyright, model_version,
-                                           app_name))
+  pmml <- append.XMLNode(pmml, .pmmlHeader(
+    description, copyright, model_version,
+    app_name
+  ))
 
   #-------------------------------------------------------------------
   # PMML -> DataDictionary
