@@ -1,8 +1,10 @@
-context("test pmml.ksvm converter")
-
 library(kernlab)
 data(iris)
 
+teardown({
+  detach("package:kernlab", unload = TRUE)
+})
+
 test_that("pmml.ksvm error when a specified kernel is not supported", {
   expect_error(
     pmml(ksvm(Sepal.Length ~ ., data = iris, kernel = "laplacedot"), dataset = iris),
