@@ -21,19 +21,19 @@ expect_equal_nn <- function(...) {
 test_that("Transformations PMML output matches R", {
   skip_on_cran()
   skip_on_ci()
-  
+
   library(zementisr)
-  
+
   box_obj <- xform_wrap(iris_p)
   box_obj <- xform_function(box_obj,
-                            orig_field_name = "sepal_length",
-                            new_field_name = "a_derived_field",
-                            expression = "sqrt(sepal_length^2 + 3)"
+    orig_field_name = "sepal_length",
+    new_field_name = "a_derived_field",
+    expression = "sqrt(sepal_length^2 + 3)"
   )
   box_obj <- xform_function(box_obj,
-                            orig_field_name = list("sepal_length, sepal_width"),
-                            new_field_name = "two_field_formula",
-                            expression = "sepal_length * sepal_width"
+    orig_field_name = list("sepal_length, sepal_width"),
+    new_field_name = "two_field_formula",
+    expression = "sepal_length * sepal_width"
   )
   fit <- lm(petal_width ~ ., data = box_obj$data)
   p_fit <- pmml(fit, transform = box_obj)
@@ -42,16 +42,16 @@ test_that("Transformations PMML output matches R", {
   z_pred <- predict_pmml_batch(iris_p, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_petal_width, r_pred)
-  
-  
+
+
   box_obj <- xform_wrap(iris_p)
   box_obj <- xform_min_max(box_obj, "1")
   box_obj <- xform_z_score(box_obj, "1", map_missing_to = 999)
   box_obj <- xform_norm_discrete(box_obj, input_var = "class")
   box_obj <- xform_function(box_obj,
-                            orig_field_name = "sepal_width",
-                            new_field_name = "a_derived_field",
-                            expression = "sqrt(sepal_width^2 - 3)"
+    orig_field_name = "sepal_width",
+    new_field_name = "a_derived_field",
+    expression = "sqrt(sepal_width^2 - 3)"
   )
   fit <- lm(petal_width ~ ., data = box_obj$data)
   p_fit <- pmml(fit, transform = box_obj)
@@ -61,24 +61,24 @@ test_that("Transformations PMML output matches R", {
   z_pred <- predict_pmml_batch(iris_p, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_petal_width, r_pred)
-  
-  
+
+
   box_obj <- xform_wrap(iris_p)
   box_obj <- xform_discretize(box_obj,
-                              xform_info = "[petal_width->dis_pw][double->string]",
-                              table = "iris_discretize_pw.csv", map_missing_to = "0", default_value = "1"
+    xform_info = "[petal_width->dis_pw][double->string]",
+    table = "iris_discretize_pw.csv", map_missing_to = "0", default_value = "1"
   )
   box_obj <- xform_discretize(box_obj,
-                              xform_info = "[sepal_length->dis_sl][double->string]",
-                              table = "iris_discretize_sl.csv", map_missing_to = "0", default_value = "1"
+    xform_info = "[sepal_length->dis_sl][double->string]",
+    table = "iris_discretize_sl.csv", map_missing_to = "0", default_value = "1"
   )
   box_obj <- xform_discretize(box_obj,
-                              xform_info = "[sepal_width->dis_sw][double->string]",
-                              table = "iris_discretize_sw.csv", map_missing_to = "0", default_value = "1"
+    xform_info = "[sepal_width->dis_sw][double->string]",
+    table = "iris_discretize_sw.csv", map_missing_to = "0", default_value = "1"
   )
   box_obj <- xform_map(box_obj,
-                       xform_info = "[class->d_class][string->double]",
-                       table = "iris_p_class_table.csv", default_value = "-1", map_missing_to = "1"
+    xform_info = "[class->d_class][string->double]",
+    table = "iris_p_class_table.csv", default_value = "-1", map_missing_to = "1"
   )
   fit <- lm(petal_length ~ ., data = box_obj$data[, -c(2, 3, 4, 5, 7)])
   p_fit <- pmml(fit, transforms = box_obj)
@@ -87,8 +87,8 @@ test_that("Transformations PMML output matches R", {
   z_pred <- predict_pmml_batch(iris_p, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_petal_length, r_pred)
-  
-  
+
+
   box_obj <- xform_wrap(audit_factor)
   box_obj <- xform_z_score(box_obj, xform_info = "column2->d_Age")
   box_obj <- xform_z_score(box_obj, xform_info = "column7->d_Income")
@@ -104,8 +104,8 @@ test_that("Transformations PMML output matches R", {
   box_obj <- xform_z_score(box_obj, xform_info = "dd_Hours->ddd_Hours")
   box_obj <- xform_norm_discrete(box_obj, input_var = "Employment")
   box_obj <- xform_map(box_obj,
-                       xform_info = "[Marital-> d_Marital][string->double]",
-                       table = "audit_marital_table.csv", default_value = "-1", map_missing_to = "1"
+    xform_info = "[Marital-> d_Marital][string->double]",
+    table = "audit_marital_table.csv", default_value = "-1", map_missing_to = "1"
   )
   fit <- rpart(Adjusted ~ ., data = box_obj$data[, -1])
   p_fit <- pmml(fit, transforms = box_obj)
@@ -117,8 +117,8 @@ test_that("Transformations PMML output matches R", {
   expect_equal_nn(z_pred$outputs$Predicted_Adjusted, r_pred_class)
   expect_equal_nn(z_pred$outputs$Probability_0, r_pred_prob[, 1])
   expect_equal_nn(z_pred$outputs$Probability_1, r_pred_prob[, 2])
-  
-  
+
+
   factor_40k_box <- xform_wrap(factor_40k)
   factor_40k_box <- xform_norm_discrete(factor_40k_box, xform_info = "CateA")
   factor_40k_box <- xform_norm_discrete(factor_40k_box, xform_info = "CateB")
@@ -132,20 +132,20 @@ test_that("Transformations PMML output matches R", {
   expect_equal_nn(z_pred$outputs$Predicted_letter, r_pred_class)
   expect_equal_nn(z_pred$outputs$Probability_A, r_pred_prob[, 1])
   expect_equal_nn(z_pred$outputs$Probability_B, r_pred_prob[, 2])
-  
-  
+
+
   numeric_10k_box <- xform_wrap(numeric_10k)
   numeric_10k_box <- xform_min_max(numeric_10k_box,
-                                   xform_info = "var_10->d_var_10", map_missing_to = "0"
+    xform_info = "var_10->d_var_10", map_missing_to = "0"
   )
   numeric_10k_box <- xform_min_max(numeric_10k_box,
-                                   xform_info = "var_11->d_var_11", map_missing_to = "0"
+    xform_info = "var_11->d_var_11", map_missing_to = "0"
   )
   numeric_10k_box <- xform_min_max(numeric_10k_box,
-                                   xform_info = "var_12->d_var_12", map_missing_to = "0"
+    xform_info = "var_12->d_var_12", map_missing_to = "0"
   )
   numeric_10k_box <- xform_min_max(numeric_10k_box,
-                                   xform_info = "var_13->d_var_13", map_missing_to = "0"
+    xform_info = "var_13->d_var_13", map_missing_to = "0"
   )
   fit <- lm(var_14 ~ ., data = numeric_10k_box$data)
   p_fit <- pmml(fit, transforms = numeric_10k_box)
@@ -155,8 +155,8 @@ test_that("Transformations PMML output matches R", {
   z_pred <- predict_pmml_batch(numeric_10k, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_var_14, r_pred, tolerance = 1e-5)
-  
-  
+
+
   numeric_10k_box <- xform_wrap(numeric_10k)
   numeric_10k_box <- xform_z_score(numeric_10k_box, xform_info = "var_0->d_var_0", map_missing_to = "0")
   numeric_10k_box <- xform_z_score(numeric_10k_box, xform_info = "var_1->d_var_1", map_missing_to = "0")
@@ -170,8 +170,8 @@ test_that("Transformations PMML output matches R", {
   z_pred <- predict_pmml_batch(numeric_10k, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_var_14, r_pred, tolerance = 1e-5)
-  
-  
+
+
   factor_10k_box <- xform_wrap(factor_10k)
   factor_10k_box <- xform_norm_discrete(factor_10k_box, input_var = "CateA")
   factor_10k_box <- xform_norm_discrete(factor_10k_box, input_var = "CateB")
@@ -186,8 +186,8 @@ test_that("Transformations PMML output matches R", {
   expect_equal_nn(z_pred$outputs$Probability_A, r_pred_prob[, 1])
   expect_equal_nn(z_pred$outputs$Probability_B, r_pred_prob[, 2])
   expect_equal_nn(z_pred$outputs$Probability_C, r_pred_prob[, 3])
-  
-  
+
+
   a <- which(factor_10k[, 1] == "A")
   b <- which(factor_10k[, 1] == "B")
   y <- which(factor_10k[, 1] == "Y")
@@ -198,8 +198,8 @@ test_that("Transformations PMML output matches R", {
   factor_10k_smp[, 1] <- as.factor(factor_10k_smp[, 1])
   factor_10k_box <- xform_wrap(factor_10k_smp)
   factor_10k_box <- xform_map(factor_10k_box,
-                              xform_info = "[letter,CateA->d_CateB][string,string->string]",
-                              table = "map_factor_400.csv", default_value = "-1", map_missing_to = "1"
+    xform_info = "[letter,CateA->d_CateB][string,string->string]",
+    table = "map_factor_400.csv", default_value = "-1", map_missing_to = "1"
   )
   fit <- rpart(letter ~ ., data = factor_10k_box$data[, -2])
   p_fit <- pmml(fit, transforms = factor_10k_box)
@@ -212,28 +212,28 @@ test_that("Transformations PMML output matches R", {
   expect_equal_nn(z_pred$outputs$Probability_A, r_pred_prob[, 1])
   expect_equal_nn(z_pred$outputs$Probability_B, r_pred_prob[, 2])
   expect_equal_nn(z_pred$outputs$Probability_Y, r_pred_prob[, 3])
-  
-  
+
+
   numeric_no_na_10k_box <- xform_wrap(numeric_no_na_10k)
   numeric_no_na_10k_box <- xform_discretize(numeric_no_na_10k_box,
-                                            xform_info = "[var_0->d_var_0][double->integer]",
-                                            table = "numeric_discretize_var.csv",
-                                            map_missing_to = "0", default_value = "1"
+    xform_info = "[var_0->d_var_0][double->integer]",
+    table = "numeric_discretize_var.csv",
+    map_missing_to = "0", default_value = "1"
   )
   numeric_no_na_10k_box <- xform_discretize(numeric_no_na_10k_box,
-                                            xform_info = "[var_1->d_var_1][double->integer]",
-                                            table = "numeric_discretize_var.csv",
-                                            map_missing_to = "0", default_value = "1"
+    xform_info = "[var_1->d_var_1][double->integer]",
+    table = "numeric_discretize_var.csv",
+    map_missing_to = "0", default_value = "1"
   )
   numeric_no_na_10k_box <- xform_discretize(numeric_no_na_10k_box,
-                                            xform_info = "[var_2->d_var_2][double->integer]",
-                                            table = "numeric_discretize_var.csv",
-                                            map_missing_to = "0", default_value = "1"
+    xform_info = "[var_2->d_var_2][double->integer]",
+    table = "numeric_discretize_var.csv",
+    map_missing_to = "0", default_value = "1"
   )
   numeric_no_na_10k_box <- xform_discretize(numeric_no_na_10k_box,
-                                            xform_info = "[var_3->d_var_3][double->integer]",
-                                            table = "numeric_discretize_var.csv",
-                                            map_missing_to = "0", default_value = "1"
+    xform_info = "[var_3->d_var_3][double->integer]",
+    table = "numeric_discretize_var.csv",
+    map_missing_to = "0", default_value = "1"
   )
   fit <- lm(var_14 ~ ., data = numeric_no_na_10k_box$data[1:600, ])
   p_fit <- pmml(fit, transforms = numeric_no_na_10k_box)
@@ -242,20 +242,20 @@ test_that("Transformations PMML output matches R", {
   z_pred <- predict_pmml_batch(numeric_no_na_10k[601:1000, ], up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_var_14, r_pred, tolerance = 1e-4)
-  
-  
+
+
   numeric_no_na_10k_box <- xform_wrap(numeric_no_na_10k)
   numeric_no_na_10k_box <- xform_min_max(numeric_no_na_10k_box,
-                                         xform_info = "var_0->d_var_0", map_missing_to = "0"
+    xform_info = "var_0->d_var_0", map_missing_to = "0"
   )
   numeric_no_na_10k_box <- xform_min_max(numeric_no_na_10k_box,
-                                         xform_info = "var_1->d_var_1", map_missing_to = "0"
+    xform_info = "var_1->d_var_1", map_missing_to = "0"
   )
   numeric_no_na_10k_box <- xform_min_max(numeric_no_na_10k_box,
-                                         xform_info = "var_2->d_var_2", map_missing_to = "0"
+    xform_info = "var_2->d_var_2", map_missing_to = "0"
   )
   numeric_no_na_10k_box <- xform_min_max(numeric_no_na_10k_box,
-                                         xform_info = "var_3->d_var_3", map_missing_to = "0"
+    xform_info = "var_3->d_var_3", map_missing_to = "0"
   )
   fit <- lm(var_14 ~ ., data = numeric_no_na_10k_box$data)
   p_fit <- pmml(fit, transforms = numeric_no_na_10k_box)
@@ -265,20 +265,20 @@ test_that("Transformations PMML output matches R", {
   z_pred <- predict_pmml_batch(numeric_no_na_10k, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_var_14, r_pred, tolerance = 1e-5)
-  
-  
+
+
   numeric_no_na_10k_box <- xform_wrap(numeric_no_na_10k)
   numeric_no_na_10k_box <- xform_z_score(numeric_no_na_10k_box,
-                                         xform_info = "var_0->d_var_0"
+    xform_info = "var_0->d_var_0"
   )
   numeric_no_na_10k_box <- xform_z_score(numeric_no_na_10k_box,
-                                         xform_info = "var_1->d_var_1", map_missing_to = "0"
+    xform_info = "var_1->d_var_1", map_missing_to = "0"
   )
   numeric_no_na_10k_box <- xform_z_score(numeric_no_na_10k_box,
-                                         xform_info = "var_2->d_var_2", map_missing_to = "0"
+    xform_info = "var_2->d_var_2", map_missing_to = "0"
   )
   numeric_no_na_10k_box <- xform_z_score(numeric_no_na_10k_box,
-                                         xform_info = "var_3->d_var_3", map_missing_to = "0"
+    xform_info = "var_3->d_var_3", map_missing_to = "0"
   )
   fit <- lm(var_14 ~ ., data = numeric_no_na_10k_box$data)
   p_fit <- pmml(fit, transforms = numeric_no_na_10k_box)
@@ -288,24 +288,24 @@ test_that("Transformations PMML output matches R", {
   z_pred <- predict_pmml_batch(numeric_no_na_10k, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_var_14, r_pred, tolerance = 1e-5)
-  
-  
+
+
   numeric_10k_box <- xform_wrap(numeric_10k)
   numeric_10k_box <- xform_discretize(numeric_10k_box,
-                                      xform_info = "[var_0->d_var_0][double->integer]",
-                                      table = "numeric_discretize_var.csv", map_missing_to = "0", default_value = "1"
+    xform_info = "[var_0->d_var_0][double->integer]",
+    table = "numeric_discretize_var.csv", map_missing_to = "0", default_value = "1"
   )
   numeric_10k_box <- xform_discretize(numeric_10k_box,
-                                      xform_info = "[var_1->d_var_1][double->integer]",
-                                      table = "numeric_discretize_var.csv", map_missing_to = "0", default_value = "1"
+    xform_info = "[var_1->d_var_1][double->integer]",
+    table = "numeric_discretize_var.csv", map_missing_to = "0", default_value = "1"
   )
   numeric_10k_box <- xform_discretize(numeric_10k_box,
-                                      xform_info = "[var_2->d_var_2][double->integer]",
-                                      table = "numeric_discretize_var.csv", map_missing_to = "0", default_value = "1"
+    xform_info = "[var_2->d_var_2][double->integer]",
+    table = "numeric_discretize_var.csv", map_missing_to = "0", default_value = "1"
   )
   numeric_10k_box <- xform_discretize(numeric_10k_box,
-                                      xform_info = "[var_3->d_var_3][double->integer]",
-                                      table = "numeric_discretize_var.csv", map_missing_to = "0", default_value = "1"
+    xform_info = "[var_3->d_var_3][double->integer]",
+    table = "numeric_discretize_var.csv", map_missing_to = "0", default_value = "1"
   )
   fit <- lm(var_14 ~ ., data = numeric_10k_box$data[1:500, ])
   p_fit <- pmml(fit, transforms = numeric_10k_box)
@@ -324,18 +324,20 @@ test_that("Transformations PMML matches R 2", {
   library(zementisr)
   iris_box_1 <- xform_wrap(iris)
 
-  iris_box_1 <- xform_function(wrap_object = iris_box_1,
-                               orig_field_name = "Sepal.Width",
-                               new_field_name = "Sepal.Width.Transformed",
-                               new_field_data_type = "numeric",
-                               expression = "Sepal.Width + 3.5"
+  iris_box_1 <- xform_function(
+    wrap_object = iris_box_1,
+    orig_field_name = "Sepal.Width",
+    new_field_name = "Sepal.Width.Transformed",
+    new_field_data_type = "numeric",
+    expression = "Sepal.Width + 3.5"
   )
 
-  iris_box_1 <- xform_function(wrap_object = iris_box_1,
-                               orig_field_name = "Sepal.Length",
-                               new_field_name = "Sepal.Length.Transformed_num",
-                               new_field_data_type = "numeric",
-                               expression = "Sepal.Length * 0.1"
+  iris_box_1 <- xform_function(
+    wrap_object = iris_box_1,
+    orig_field_name = "Sepal.Length",
+    new_field_name = "Sepal.Length.Transformed_num",
+    new_field_data_type = "numeric",
+    expression = "Sepal.Length * 0.1"
   )
 
   set.seed(321)
@@ -346,25 +348,24 @@ test_that("Transformations PMML matches R 2", {
   z_pred <- predict_pmml_batch(iris, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_Petal.Length, r_pred, tolerance = 1e-4)
-
 })
 
 test_that("Using box data with no transforms matches", {
   skip_on_cran()
   skip_on_ci()
-  
+
   library(zementisr)
-  
+
   iris_box_1 <- xform_wrap(iris)
   fit <- lm(Petal.Length ~ Species, data = iris_box_1$data)
-  
+
   p_fit <- pmml(fit, transforms = iris_box_1)
   r_pred <- as.numeric(predict(fit, iris_box_1$data))
   up_stat <- upload_model(p_fit)
   z_pred <- predict_pmml_batch(iris, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_Petal.Length, r_pred, tolerance = 1e-4)
-  
+
   # save_pmml(p_fit, "../../../temp/iris_lm_empty_transf.pmml")
   # pred_df <- iris
   # pred_df$Predicted_Petal.Length <- r_pred
@@ -375,26 +376,27 @@ test_that("Using box data with no transforms matches", {
 test_that("Transformation preserves numeric when input is unchanged", {
   skip_on_cran()
   skip_on_ci()
-  
+
   library(zementisr)
-  
+
   iris_box_1 <- xform_wrap(iris)
-  iris_box_1 <- xform_function(wrap_object = iris_box_1,
-                               orig_field_name = "Sepal.Length",
-                               new_field_name = "Sepal.Length_transf",
-                               new_field_data_type = "numeric",
-                               expression = "Sepal.Length"
+  iris_box_1 <- xform_function(
+    wrap_object = iris_box_1,
+    orig_field_name = "Sepal.Length",
+    new_field_name = "Sepal.Length_transf",
+    new_field_data_type = "numeric",
+    expression = "Sepal.Length"
   )
-  
+
   fit <- lm(Petal.Length ~ Sepal.Length_transf, data = iris_box_1$data)
-  
+
   p_fit <- pmml(fit, transforms = iris_box_1)
   r_pred <- as.numeric(predict(fit, iris_box_1$data))
   up_stat <- upload_model(p_fit)
   z_pred <- predict_pmml_batch(iris, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_Petal.Length, r_pred, tolerance = 1e-4)
-  
+
   # save_pmml(p_fit, "../../../temp/iris_lm_numeric.pmml")
   # pred_df <- iris
   # pred_df$Predicted_Petal.Length <- r_pred
@@ -404,19 +406,20 @@ test_that("Transformation preserves numeric when input is unchanged", {
 test_that("Transformation preserves factor when input is unchanged", {
   skip_on_cran()
   skip_on_ci()
-  
+
   library(zementisr)
-  
+
   iris_box_1 <- xform_wrap(iris)
-  iris_box_1 <- xform_function(wrap_object = iris_box_1,
-                               orig_field_name = "Species",
-                               new_field_name = "Species_transf",
-                               new_field_data_type = "factor",
-                               expression = "Species"
+  iris_box_1 <- xform_function(
+    wrap_object = iris_box_1,
+    orig_field_name = "Species",
+    new_field_name = "Species_transf",
+    new_field_data_type = "factor",
+    expression = "Species"
   )
-  
+
   fit <- lm(Petal.Length ~ Species_transf, data = iris_box_1$data)
-  
+
   p_fit <- pmml(fit, transforms = iris_box_1)
   r_pred <- as.numeric(predict(fit, iris_box_1$data))
   up_stat <- upload_model(p_fit)
@@ -436,65 +439,67 @@ test_that("Transformation preserves factor names when input is numeric", {
   skip("skip")
   skip_on_cran()
   skip_on_ci()
-  
+
   library(zementisr)
   iris_box_5 <- xform_wrap(iris)
-  iris_box_5 <- xform_function(wrap_object = iris_box_5,
-                               orig_field_name = "Sepal.Length",
-                               new_field_name = "Sepal.Length_transf",
-                               new_field_data_type = "factor",
-                               expression = "Sepal.Length")
-  
+  iris_box_5 <- xform_function(
+    wrap_object = iris_box_5,
+    orig_field_name = "Sepal.Length",
+    new_field_name = "Sepal.Length_transf",
+    new_field_data_type = "factor",
+    expression = "Sepal.Length"
+  )
+
   fit <- lm(Petal.Length ~ Sepal.Length_transf, data = iris_box_5$data)
-  
+
   p_fit <- pmml(fit, transforms = iris_box_5)
   r_pred <- as.numeric(predict(fit, iris_box_5$data))
   up_stat <- upload_model(p_fit)
   z_pred <- predict_pmml_batch(iris, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_Petal.Length, r_pred, tolerance = 1e-4)
-  
+
   # save_pmml(p_fit, "../../../temp/iris_lm_num_to_factor.pmml")
   # pred_df <- iris
   # pred_df$Predicted_Petal.Length <- r_pred
   # write.csv(pred_df, "../../../temp/iris_lm_num_to_factor.csv", row.names = FALSE)
-  
 })
 
 test_that("PMML matches R with multiple xform_function transformations - 1", {
   skip_on_cran()
   skip_on_ci()
-  
+
   library(zementisr)
 
   iris_box_1 <- xform_wrap(iris)
 
-  iris_box_1 <- xform_function(wrap_object = iris_box_1,
-                               orig_field_name = "Sepal.Length",
-                               new_field_name = "Sepal.Length.T2",
-                               new_field_data_type = "factor",
-                               expression = "if(Sepal.Length < 5){'less'} else {'more'}"
+  iris_box_1 <- xform_function(
+    wrap_object = iris_box_1,
+    orig_field_name = "Sepal.Length",
+    new_field_name = "Sepal.Length.T2",
+    new_field_data_type = "factor",
+    expression = "if(Sepal.Length < 5){'less'} else {'more'}"
   )
 
-  iris_box_1 <- xform_function(wrap_object = iris_box_1,
-                               orig_field_name = "Sepal.Width",
-                               new_field_name = "Sepal.Width.Transformed",
-                               new_field_data_type = "numeric",
-                               expression = "Sepal.Width + 3.5"
+  iris_box_1 <- xform_function(
+    wrap_object = iris_box_1,
+    orig_field_name = "Sepal.Width",
+    new_field_name = "Sepal.Width.Transformed",
+    new_field_data_type = "numeric",
+    expression = "Sepal.Width + 3.5"
   )
 
   fit <- lm(Petal.Length ~ Species + Sepal.Length.T2 + Sepal.Width.Transformed, data = iris_box_1$data)
-  
+
   p_fit <- pmml(fit, transforms = iris_box_1)
   r_pred <- as.numeric(predict(fit, iris_box_1$data))
   up_stat <- upload_model(p_fit)
   z_pred <- predict_pmml_batch(iris, up_stat$model_name)
   delete_model(up_stat$model_name)
   expect_equal_nn(z_pred$outputs$Predicted_Petal.Length, r_pred, tolerance = 1e-4)
-  
+
   # save_pmml(p_fit, "../../../temp/iris_lm.pmml")
   # pred_df <- iris
   # pred_df$Predicted_Petal.Length <- r_pred
   # write.csv(pred_df, "../../../temp/iris_lm.csv", row.names = FALSE)
-  
-})
\ No newline at end of file
+})
