@@ -1,17 +1,8 @@
-# library(amap)
 library(clue)
 library(data.table)
-# library(glmnet)
-# library(ada)
-# library(gbm)
 library(caret)
-# library(randomForest)
-# library(xgboost)
 library(Matrix)
-# library(e1071)
 library(neighbr)
-# library(nnet)
-# library(kernlab)
 library(forecast)
 
 data(iris)
@@ -139,15 +130,13 @@ zmz_transform_audit <- function(box_obj) {
 
 
 schema <- XML::xmlSchemaParse("pmml-4-4.xsd") # updated schema includes ObservationVarianceMatrix and InterceptVector
-# schema <- XML::xmlSchemaParse("pmml-4-4_statespace.xsd")
-
 
 test_that("TimeSeries/Arima PMML validates against schema", {
   skip_on_cran()
   skip_on_ci()
 
   skip_if_not_installed("forecast")
-  library()
+  # library()
 
   fit <- Arima(WWWusage, order = c(1, 0, 1))
   expect_equal(validate_pmml(pmml(fit), schema), 0)
@@ -187,28 +176,6 @@ test_that("TimeSeries/Arima PMML validates against schema", {
 
   fit <- Arima(USAccDeaths, order = c(3, 1, 1), seasonal = c(1, 1, 0))
   expect_equal(validate_pmml(pmml(fit, ts_type = "statespace"), schema), 0)
-
-
-
-  # The following tests fail since TransitionMatrix and MeasurementMatrix have been removed from ELS representation
-  # fit <- Arima(JohnsonJohnson, order = c(0, 1, 0), seasonal = c(0, 1, 2))
-  # expect_equal(validate_pmml(pmml(fit, ts_type = "arima"), schema), 0)
-  #
-  # fit <- Arima(AirPassengers, order = c(0, 1, 1), seasonal = c(0, 1, 1))
-  # expect_equal(validate_pmml(pmml(fit), schema), 0)
-  #
-  # fit <- Arima(JohnsonJohnson, order = c(0, 1, 0), seasonal = c(0, 1, 2))
-  # expect_equal(validate_pmml(pmml(fit, exact_least_squares = TRUE), schema), 0)
-  #
-  # fit <- Arima(AirPassengers, order = c(0, 1, 1), seasonal = c(0, 1, 1))
-  # expect_equal(validate_pmml(pmml(fit, exact_least_squares = TRUE), schema), 0)
-  #
-  # fit <- Arima(JohnsonJohnson, order = c(2, 1, 3), seasonal = c(0, 1, 2))
-  # expect_equal(validate_pmml(pmml(fit, exact_least_squares = TRUE), schema), 0)
-  #
-  # fit <- Arima(AirPassengers, order = c(4, 2, 1), seasonal = c(1, 1, 1))
-  # expect_equal(validate_pmml(pmml(fit, exact_least_squares = TRUE), schema), 0)
-  #
 })
 
 
